/*!
 * Copyright (c) 2019 Contributors to the Eclipse Foundation
 *
 * See the NOTICE file(s) distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0
 *
 * SPDX-License-Identifier: EPL-2.0
 */
import { BasicAuth, HttpBasicAuth } from '@eclipse-ditto/ditto-javascript-client-api_1.0';
/**
 * Dom implementation of a Base64 encoder.
 */
export class DomBase64Encoder {
    encodeBase64(toEncode) {
        return btoa(toEncode);
    }
}
/**
 * Dom implementation of basic auth for HTTP connections.
 */
export class DomHttpBasicAuth extends HttpBasicAuth {
    constructor(username, password, encoder) {
        super(username, password, encoder);
    }
    /**
     * Create basic authentication for HTTP connections.
     * @param username - The username.
     * @param password - the password.
     */
    static newInstance(username, password) {
        return new DomHttpBasicAuth(username, password, new DomBase64Encoder());
    }
}
/**
 * Dom implementation of basic auth for WebSocket connections.
 */
export class DomWebSocketBasicAuth extends BasicAuth {
    constructor(username, password, encoder) {
        super(username, password, encoder);
    }
    /**
     * Create basic authentication for Http connections.
     * @param username - The username.
     * @param password - the password.
     */
    static newInstance(username, password) {
        return new DomWebSocketBasicAuth(username, password, new DomBase64Encoder());
    }
    authenticateWithHeaders(originalHeaders) {
        return originalHeaders;
    }
    authenticateWithUrl(originalUrl) {
        return originalUrl.withDomain(`${encodeURIComponent(this.username)}:${encodeURIComponent(this.password)}@${originalUrl.domain}`);
    }
}
//# sourceMappingURL=dom-auth.js.map